@@ -1,5 +1,6 @@
 #![allow(clippy::upper_case_acronyms)]
 #![allow(clippy::needless_pass_by_value)]
+#![allow(clippy::pedantic)]
 #![cfg(not(target_os = "windows"))]
 
 use std::convert::From;
@@ -24,8 +25,8 @@ pub mod tbp_flags {
 pub struct TaskbarProgress {}
 
 impl TaskbarProgress {
-    pub fn new() -> TaskbarProgress {
-        TaskbarProgress {}
+    pub fn new() -> Self {
+        Self {}
     }
 
     pub fn set_progress_state(&self, _tbp_flags: TBPFLAG) {}
@@ -36,12 +37,13 @@ impl TaskbarProgress {
 
     pub fn show(&self) {}
 
+    #[allow(clippy::needless_pass_by_ref_mut)]
     pub fn release(&mut self) {}
 }
 
 impl From<HWND> for TaskbarProgress {
     fn from(_hwnd: HWND) -> Self {
-        TaskbarProgress {}
+        Self {}
     }
 }
 
